@@ -24,6 +24,10 @@
 #ifndef KEXIV2_PRIVATE_H
 #define KEXIV2_PRIVATE_H
 
+#if defined( HAVE_CONFIG_H )
+#include "config.h"
+#endif
+
  // C++ includes.
 
 #include <cstdlib>
@@ -54,6 +58,9 @@
 // See http://gcc.gnu.org/wiki/Visibility, the section about c++ exceptions.
 // They are needed for all libexiv2 versions that do not care about visibility.
 #pragma GCC visibility push(default)
+#if defined(HAVE_EXIV2_HPP)
+#include <exiv2/exiv2.hpp>
+#else
 #include <exiv2/error.hpp>
 #include <exiv2/image.hpp>
 #include <exiv2/jpgimage.hpp>
@@ -61,6 +68,7 @@
 #include <exiv2/tags.hpp>
 #include <exiv2/types.hpp>
 #include <exiv2/exif.hpp>
+#endif
 #pragma GCC visibility pop
 
 // Check if Exiv2 support XMP
